import type { Framework } from '@roots/bud-framework';
import { NormalizedPlugin, Registrable, Registry } from './babel.interface';
/**
 * Configure Babel transpiler plugin & presets
 *
 * @example
 * ```js
 * app.babel.setPlugins([
 *  ['@babel/plugin-transform-runtime', {helpers: false}],
 *  '@babel/plugin-proposal-object-rest-spread',
 *  '@babel/plugin-syntax-dynamic-import',
 *  '@babel/plugin-proposal-class-properties',
 * ])
 * ```
 *
 * @public @extension @config
 */
export interface Config {
    /**
     * Registered babel plugins
     *
     * @public
     */
    plugins: Registry;
    /**
     * Registered babel presets
     *
     * @public
     */
    presets: Registry;
    /**
     * Add a babel plugin
     *
     * @example
     * ```js
     * babel.setPlugin(MyPlugin, {plugin: 'options'})
     * ```
     *
     * @public
     */
    setPlugin(plugin: Registrable): Config;
    /**
     * Add babel plugins
     *
     * @public
     */
    setPlugins(plugins: Array<Registrable>): Config;
    /**
     * Set the options for a plugin
     *
     * @public
     */
    setPluginOptions(plugin: string, options: any): Config;
    /**
     * Add a babel preset
     *
     * @example
     * ```js
     * babel.setPlugin(MyPlugin, {plugin: 'options'})
     * ```
     *
     * @public
     */
    setPreset(preset: Registrable): Config;
    /**
     * Add babel presets
     *
     * @public
     */
    setPresets(presets: Array<NormalizedPlugin | string>): Config;
    /**
     * Set the options for a preset
     *
     * @public
     */
    setPresetOptions(preset: string, options: any): Config;
}
export declare class Config {
    /**
     * @public
     */
    name: string;
    /**
     * @internal
     */
    _app: () => Framework;
    /**
     * @public
     */
    plugins: Registry;
    /**
     * @public
     */
    presets: Registry;
    /**
     * @public
     */
    get app(): Framework;
    constructor(app: Framework);
    normalizeEntry(c: Registrable): NormalizedPlugin;
    unsetPreset(preset: string): this;
    unsetPlugin(plugin: string): this;
}
//# sourceMappingURL=babel.config.d.ts.map